// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef LIBKLEO_VERSION_H
#define LIBKLEO_VERSION_H

#define LIBKLEO_VERSION_STRING "5.19.1"
#define LIBKLEO_VERSION_MAJOR 5
#define LIBKLEO_VERSION_MINOR 19
#define LIBKLEO_VERSION_PATCH 1
#define LIBKLEO_VERSION ((5<<16)|(19<<8)|(1))

#endif
